//
//  TiltViewController.swift
//  FaceTilt
//
//  Created by Sally McNichols on 10/26/14.
//  Copyright (c) 2014 CMU iOS Development StuCo. All rights reserved.
//

import UIKit
import CoreMotion

class TiltViewController: UIViewController {
    let kTiltViewControllerMarbleSize: CGFloat = 150.0
    var imageView: UIImageView = UIImageView()
    var motionManager: CMMotionManager = CMMotionManager()
    var marble: Marble!
    var tap = UITapGestureRecognizer()
    
    override func viewWillAppear(animated: Bool) {
        // hide nav bar
        self.navigationController?.navigationBarHidden = true

    }
    
    //hide status bar
    override func prefersStatusBarHidden() -> Bool {
        return true
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // initialize values for marble to start out at (0,0) which is in upper left corner for UIViews
        let marbleSize: CGSize = CGSizeMake(kTiltViewControllerMarbleSize, kTiltViewControllerMarbleSize)
        self.imageView.frame = CGRect(origin: CGPointZero, size: marbleSize)
        // make the image appear circular
        self.imageView.layer.cornerRadius = kTiltViewControllerMarbleSize / 2.0
        self.imageView.clipsToBounds = true
        // create marble
        self.marble = Marble(size: marbleSize)
        
        // tell CMMotionManager to start collecting data from accelerometer and gyroscope
        self.motionManager.startAccelerometerUpdates()
        self.motionManager.startGyroUpdates()
        
        // make sure to add the "marble image" to the view
        self.view.addSubview(self.imageView)
        
        // set up a tap gesture recognizer so that you can tap to go back
        // to the PictureViewController
        self.tap.addTarget(self, action: "tappedView")
        self.view.addGestureRecognizer(tap)
        
        // create a timer to get updates for accelerometer/gyro constantly so that marble moves around
        // according to accelerometer and gyroscope readings
        NSTimer.scheduledTimerWithTimeInterval(0.0, target: self, selector:"updateMarble:", userInfo: nil, repeats: true)
    }
    
    func updateMarble(timer: NSTimer) -> Void {
        // handle translations
        // make sure that accelerometer has collected data and then get the data
        // in order to update the marble and make the image move around
        if(self.motionManager.accelerometerData != nil) {
            var acceleration = MarbleAcceleration(xAccel: self.motionManager.accelerometerData!.acceleration.x, yAccel: self.motionManager.accelerometerData!.acceleration.y)
        
            self.marble.updateMarbleAcceleration(acceleration)
            
            self.imageView.center = self.marble.center()
        }
        
        // handle rotations about z axis
        // make sure that the gyroscope has collected data and then get the data
        // in order to make the marble rotate around
        if(self.motionManager.gyroData != nil) {
            self.marble.updateMarbleRotation(self.motionManager.gyroData!.rotationRate.z)
            self.imageView.transform = self.marble.rotation()
        }
    }
    
    func tappedView() -> Void{
        self.motionManager.stopAccelerometerUpdates()
        self.motionManager.stopGyroUpdates()
        self.navigationController?.popViewControllerAnimated(true)
    }
    
}
